@@ -17,14 +17,15 @@ STORE_DIR = os.path.join(CONFIG_DIR, 'matrix-store')
 IDENTIFIER = "MX"
 User = None
 
+app_log = setup_logging("matrix")
+
+
 async def message_callback(room: MatrixRoom, event: RoomMessageText) -> None:
-    print(
+    app_log.info(
         f"Message received in room {room.display_name}\n"
         f"{room.user_name(event.sender)} | {event.body}"
     )
     is_group = len(room.users.keys()) > 2 or room.is_named
-    if 'Löwenherz' in room.display_name:
-        print("Löwenherz!")
 
     if is_group and not room.is_named:
         room_name = ', '.join([user.display_name for id, user in room.users.items() if id != room.own_user_id])
@@ -32,7 +33,7 @@ async def message_callback(room: MatrixRoom, event: RoomMessageText) -> None:
         room_name = room.display_name
 
     chat_info = {
-        'ID': event.server_timestamp,
+        'ID': event.event_id,
         'date': datetime.utcfromtimestamp(event.server_timestamp / 1000),
         'type': 'Group' if is_group else 'User'
     }
@@ -43,8 +44,7 @@ async def message_callback(room: MatrixRoom, event: RoomMessageText) -> None:
                 'to': room_name
             })
         else:
-            to_id = list(filter(lambda u: u != User, room.users))[0]
-            to_user = room.users[to_id]
+            to_user = [user for u_id, user in room.users.items() if u_id != event.sender][0]
             chat_info.update({
                 'to_id': to_user.user_id,
                 'to': to_user.display_name
@@ -71,11 +71,10 @@ async def main() -> None:
     if STORE_DIR and not os.path.isdir(STORE_DIR):
         os.mkdir(STORE_DIR)
 
-    client = None
     client_config = ClientConfig(store_sync_tokens=True)
     # If there are no previously-saved credentials, we'll use the password
     if not os.path.exists(CONFIG_FILE):
-        print("First time use. Did not find credential file. Using supplied "
+        app_log.info("First time use. Did not find credential file. Using supplied "
               "homeserver, user, and password to create credential file.")
         if not (MATRIX_HS_URL.startswith("https://")
                 or MATRIX_HS_URL.startswith("http://")):
@@ -110,7 +109,7 @@ async def main() -> None:
     # await client.join("your-room-id")
 
     # Load devices & keys
-    #client.load_store()
+    client.load_store()
     
 
     
